---

Tag: ["Science", "🩺", "🧠"]
Date: 2022-10-12
DocType: "WebClipping"
Hierarchy:
TimeStamp: 2022-10-12
Link: https://nautil.us/a-new-doorway-to-the-brain-242099/
location:
CollapseMetaTable: true

---

Parent:: [[@News|News]]
Read:: [[2022-10-15]]

---

&emsp;

```button
name Save
type command
action Save current file
id Save
```
^button-ANewDoorwaytotheBrainNSave

&emsp;

# A New Doorway to the Brain

The brain’s lifeline, its network of blood vessels, is like a tree, says Mathieu Pernot, deputy director of the Physics for Medicine Paris Lab. The trunk begins in the neck with the carotid arteries, a pair of broad channels that then split into branches that climb into the various lobes of the brain. These channels fork endlessly into a web of tiny vessels that form a kind of canopy. The narrowest of these vessels are only wide enough for a single red blood cell to pass through, and in one important sense these vessels are akin to the tree’s leaves.

“When you want to look at pathology, usually you don’t see the sickness in the tree, but in the leaves,” Pernot says. (You can identify Dutch Elm Disease when the tree’s leaves yellow and wilt.) Just like leaves, the tiniest blood vessels in the brain often register changes in neuron and synapse activity first, including illness, such as new growth in a cancerous brain tumor.1, 2 But only in the past decade or so have we developed the technology to detect these microscopic changes in blood flow: It’s called ultrafast ultrasound.

> The images show activity in deep regions of the brain where past imaging couldn’t reach.

Standard ultrasound is already popular in clinical imaging given that it is minimally invasive, low-cost, portable, and can generate images in real time.3 But until now, it has rarely been used to image the brain. That’s partly because the skull gets in the way—bone tends to scatter ultrasound waves—and the technology is too slow to detect blood flow in the smaller arteries that support most brain function. Neurologists have mostly used it in niche applications: to examine newborns, whose skulls have gaps between the bone plates, or to guide surgeons in some brain surgeries, where part of the skull is typically removed. Neuroscience researchers have also used it to study functional differences between the two hemispheres of the brain, based on imaging of the major cerebral arteries, by positioning the device over the temporal bone window, the thinnest area of the skull.

But ultrafast ultrasound is exponentially faster, more powerful, and more spatially sensitive than standard ultrasound: It can produce many thousands of detailed high-resolution images per second.3 If conventional ultrasound is like peeking through a keyhole, ultrafast ultrasound “opens the whole door,” says Peifeng Song, who researches ultrasound techniques at the University of Illinois Urbana-Champaign. Neuroscientists say it could not only help doctors make much earlier diagnoses of debilitating brain diseases, such as brain cancer or Alzheimer’s, but could also aid neuroscientists working with animal models in solving major research questions and accelerate the development of non-invasive brain-machine interfaces, such as robotic limbs.

“If you talk about neuroscience and how the brain works, there’s a lot of unknowns,” Song says. “It’s the wild west.” Ultrafast ultrasound could trace brain signaling with great precision, documenting how circuits and groups of cells interact as the brain performs functions from perception to decision-making.

Functional ultrasound imaging works by the process of echolocation, the same process bats use to navigate. Too high pitched for humans to hear, ultrasound waves collide with tissues or cells in the body and reflect out. Their echoes can then be captured and used to calculate the locations and velocities of blood cells. The frequencies of the returning ultrasound waves reveal where blood is flowing, supplying oxygen and glucose to brain regions that are working especially hard, or conversely, which parts of the brain are not receiving the blood and nutrients they need. These images allow researchers and clinicians to get a sense of what parts of the brain are active—for example, regions responsible for decision-making—or which ones might be at risk of damage.4

In the last decade or so, advances in computer processing power have allowed researchers to transform ultrasound technology. Instead of emitting individual beams, these newer ultrasound systems send out a series of plane waves—an array of ultrasound beams that together form a plane—that hit their target at different angles. The resulting images are composites that are multiple orders of magnitude sharper than conventional ultrasound, MRI, or CT scans, without the trade-offs faced by other imaging methods. MRI machines, for example, demand hugely powerful and expensive magnets to improve their resolution.5 The new forms of ultrasound can also work up to 100 times faster than conventional ultrasound tools, which is especially useful during medical emergencies, when time is of the essence. Such speeds allow ultrasound to track seizures as they happen, Pernot says.

“Even just a few years ago, that type of data throughput would have just been mountainous,” says Sumner Norman, a postdoc at Caltech. “So you wouldn’t have been able to do much with it.” But as computer capacity caught up with the demand, ultrafast ultrasound became more feasible. In Song’s lab, their 3-D ultrasound imaging requires around 10 terabytes of data to fully image the brain of each lab animal in 3-D—the same amount it would take to stream Netflix in standard definition for 10,000 hours.

![](https://assets.nautil.us/sites/3/nautilus/D7ZuA8xq-Renken_BREAKER.png?auto=compress&fm=png&ixlib=php-3.3.1)

**Bubbles in the Brain:** Ultrasound localization microscopy takes high resolution images of blood flow in the brain by bouncing ultrasound waves off of microscopic gas bubbles injected into the blood. *Credit: Junjie Yao’s lab at Duke University.*

Now that researchers have the computing power to create such high-speed, fine-grained images, they can also track the movement of cells over time. [Research](https://www.nature.com/articles/s41592-022-01549-5) published in August by the lab of Mickael Tanter of PSL Research University in France depicted activity throughout the rat brain at a microscopic level.6 The images show activity in deep regions of the brain where light-based imaging can’t reach, and in stunning detail—much finer resolution than an MRI or CT scan. The pictures showed activity from second to second down to a scale of a few thousands of a millimeter.

In humans, ultrasound researchers are finding creative ways to work around the impediment of the skull. Fabienne Perren at the University of Geneva and colleagues, including Tanter, used a [contrast agent](https://neurocenter-unige.ch/humain-brain-vascularisation-revealed-by-ultrafast-ultrasounds-at-a-microscopic-level-for-the-first-time/)—microbubbles of gas injected into patients’ blood.7 Some waves still collide with the skull and scatter, but the ones that make it through are more likely to reflect back out when they bounce off the bubbles. Where a CT scan showed only a blob, ultrasound imaging allowed the team to zoom in until they could pinpoint the turbulence inside a bulging blood vessel. Tanter’s lab has also sent ultrasound signals through the gaps between newborns’ skull plates to record [brain activity during seizures and sleep](https://www.science.org/doi/full/10.1126/scitranslmed.aah6756).8

Scientists can also remove a small piece of the skull to facilitate working with ultrasound. Working with monkeys, Norman and his colleagues replaced a domino-sized piece of the skull with an ultrasound device. The images of activity in a part of the brain that plans movement revealed when a monkey intended to move an arm. In fact, they could predict the direction of the movement [about 89 percent of the time](https://www.sciencedirect.com/science/article/pii/S0896627321001513?dgcid=coauthor).9 This is comparable to methods that implant electrodes in the scalp, which have been reported to accurately predict direction of movement roughly 70 to 90 percent of the time.

> You can’t wheel an MRI machine onto a battlefield. But you can take a handheld device.

But ultrasound imaging does a better job detecting activity deep within the brain, which is harder for electrodes on the scalp to detect. Electrodes are also far more invasive and can cause tissue damage. And the rapidly accelerating capacities of ultrasound will bring improvements, researchers expect. These findings were published last year in *Neuron* and could pave the way for robotic limbs that translate thought into action: Ultrasound imaging could read brain activity, revealing how a person wants to move their hand to the left, and that data could be fed into a computer that controls a robotic arm, for instance. “We’re already moving toward humans,” Norman says.

Ultrafast ultrasound could also assist surgeons, who often remove pieces of bone before operating anyway. Zin Khaing, an assistant professor of neurological surgery at the University of Washington, is [now testing](https://reporter.nih.gov/search/Woq41Wvmu0mJxWqTQ3QCog/project-details/10179815) enhanced ultrasound on spinal surgery patients. “If I were to get injured today,” she says, “you would do a CT or an X-ray.” Perhaps an MRI, too. But these only produce anatomical images. “It just shows you where all the bits and pieces are, and what’s squishing onto your soft spinal cord tissue,” Khaing says. Imaging that tracks blood flow is not part of the protocol.

In her pilot clinical trial, ultrafast ultrasound is used in the operating room so doctors can follow the movement of blood. Zhaing is aiming to map what tissue still has blood flow, so that doctors can know what will be salvageable, and what areas are still swollen—perhaps where the surgeon should relieve pressure. She hopes ultrasound could guide surgery even in geographies with fewer resources. “You can’t wheel an MRI machine to a war situation, right? But you can have a handheld ultrasound device,” she says. Plus, she imagines ultrasound technology that’s even easier to use than a probe: something more like a bandaid. MIT researchers have already developed [thin ultrasound stickers](https://www.science.org/doi/10.1126/science.abo2542) that can monitor organs over time without a doctor holding an ultrasound wand.10

At the Physics for Medicine Paris Lab, Pernot is hopeful that scientists will be able to correct for the skull’s effects on ultrasound waves. In the same way that researchers can compensate for a flaw in the lens of a telescope, they could also use an algorithm to adjust for the way the skull scatters ultrasound signals, he says. X-rays that map the exact geometry of a skull can guide a model of exactly how the skull distorts ultrasound waves, says Junjie Yao, a researcher at Duke who develops technology that uses both ultrasound and light-based imaging. And that model can be used to correct ultrasound images so they appear undistorted, as though there weren’t any skull there at all. “I wouldn’t say it’s impossible to overcome the hurdle of the skull, but it will be an engineering challenge,” Yao adds.

Ultrasound imaging is still evolving rapidly. “New ideas are popping up every day,” Yao says. Norman was impressed by how quickly his work progressed—in only a few years, he moved from small animal tests to large animal experiments and showed the potential of ultrasound to read brain activity that could feed into a computer.9 “It was incredible how quickly it moved. Usually when you start a new technology, you’re in for a decades-long slog to make it work,” he says. But when computer processing accelerated, the benefits of ultrafast ultrasound became clear. Now researchers can follow rivulets of blood deep into the brain. “We are going to have an imaging technique to go into another world,” Tanter says. ![](https://assets.nautil.us/sites/3/nautilus/nautilus-favicon-14.png?fm=png)

*Research into the use of contrast agents in ultrafast ultrasound by Fabienne Perren is funded by the Bertarelli Foundation.*

*Lead image: Paul Craft / Shutterstock*

**References**

1\. Guyon, J., Chapouly, C., Andrique, L., Bikfalvi, A., & Daubon, T. The normal and brain tumor vasculature: Morphological and functional characteristics and therapeutic targeting. *Frontiers in Physiology* **12**, 622615 (2021).

2\. Baloyannis, S. Brain capillaries in Alzheimer’s disease. *Hellenic Journal of Nuclear Medicine* **1:152** (2015).

3\. Deffieux, T., Demené, C., & Tanter, M. Functional ultrasound imaging: A new imaging modality for neuroscience. *Neuroscience* **474**, 110-121 (2021).

4\. Montaldo, G., Urban, A., & Macé, E. Functional ultrasound neuroimaging. *Annual Review of Neuroscience* **45**, 491-513 (2022).

5\. Nowogrodzki, A. The world’s strongest MRI machines are pushing human imaging to new limits. *Nature* (2018).

6\. Renaudin, N., *et al.* Functional ultrasound localization microscopy reveals brain-wide neurovascular activity on a microscopic scale. *Nature Methods* **19**, 1004-1012 (2022).

7\. Demené, C., *et al.* Transcranial ultrafast ultrasound localization microscopy of brain vasculature in patients. *Nature Biomedical Engineering* **5**, 219-228 (2021).

8\. Demené, C., *et al.* Functional ultrasound imaging of brain activity in human newborns. *Science Translational Medicine* **9** (2017).

9\. Norman, S.L., *et al.* Single-trial decoding of movement intentions using functional ultrasound neuroimaging. *Neuron* **109**, 1554-1566 (2021).

10\. Wang, C., *et al.* Bioadhesive ultrasound for long-term continuous imaging of diverse organs. *Science* **377**, 517-523 (2022).

-   ###### Elena Renken
    
    Posted on October 11, 2022
    
    Elena Renken is a science reporter focusing on the brain and medicine. Her work has been published by NPR, *Quanta Magazine*, and PBS NOVA.
    

### Published in partnership with:

![new_letter](data:image/svg+xml,%3Csvg%20xmlns=%22http://www.w3.org/2000/svg%22%20viewBox=%220%200%20210%20140%22%3E%3C/svg%3E)

#### Get the Nautilus newsletter

The newest and most popular articles delivered right to your inbox!

&emsp;
&emsp;

---
`$= dv.el('center', 'Source: ' + dv.current().Link + ', ' + dv.current().Date.toLocaleString("fr-FR"))`